class _Endpoint(object):
    """
    Base class for all endpoints.
    """

    def __init__(self, requester):
        self._requester = requester

    def _expanded_path(self, path=None):
        """Gets the expanded path, given this endpoint"""
        return "/{expanded_path}".format(
            expanded_path="/".join(p for p in (self.endpoint, path) if p)
        )

    def GET(self, url):
        """
        Make a GET request to the API.
        """
        return self._requester.get_request(self._expanded_path(url))

    def POST(self, url, data):
        """
        Make a POST request to the API.
        """
        return self._requester.post_request(self._expanded_path(url), data)



"""
Munzee API wrapper.
"""
# import json

import json

import requests

from munzee.endpoints import Clans, Map, Munzees, Players, Statzee


class Munzee:
    """
    Munzee API wrapper.
    """

    def __init__(self, api_key):
        self._api_key = api_key
        self.base_url = "https://api.munzee.com/"

        """Setup the base_requester for the API."""
        self.base_requester = self.Requester(self._api_key)
        self.users = Players(self.base_requester)
        self.munzees = Munzees(self.base_requester)
        self.map = Map(self.base_requester)
        self.clans = Clans(self.base_requester)
        self.statzee = Statzee(self.base_requester)

    class Requester(object):
        """Api requesting object"""

        def __init__(self, api_key):
            self._api_key = api_key
            self.base_url = "https://api.munzee.com"

        def get_request(self, url):
            """
            Make a GET request to the API.
            """
            headers = {"Authorization": "Bearer " + self._api_key}
            response = requests.get(self.base_url + url, headers=headers)
            return response.json()

        def post_request(self, url, data):
            """
            Make a POST request to the API.
            """
            headers = {"Authorization": "Bearer " + self._api_key}
            files = {"data": (None, json.dumps(data))}
            response = requests.post(self.base_url + url, headers=headers, files=files)
            return response.json()



from munzee.endpoints.clan import Clans
from munzee.endpoints.map import Map
from munzee.endpoints.munzee import Munzees
from munzee.endpoints.player import Players
from munzee.endpoints.statzee import Statzee

__all__ = ["Players", "Munzees", "Map", "Clans","Statzee"]



from munzee.endpoint import _Endpoint


class Munzees(_Endpoint):
    """Endpoint class for munzees."""

    endpoint = "munzee"

    def get_munzee_by_id(self, id: int, closest=0):
        """
        Get a Munzee by ID.
        """
        return self.POST("", {"munzee_id": id, "closest": closest})

    def get_munzee_by_url(self, url: str, closest=0):
        """
        Get a Munzee by URL.
        """
        return self.POST("", {"url": url, "closest": closest})

    def get_latest_logs(self, munzee_id: int):
        """
        Get the latest logs for a Munzee.
        """
        return self.POST("logs", {"munzee_id": munzee_id})

    def has_user_captured_munzee(self, munzee_id: int):
        """
        Check if a user has captured a Munzee.
        """
        return self.POST("hascaptured", {"munzee_ids": munzee_id})



from munzee.endpoint import _Endpoint


class Map(_Endpoint):
    """Endpoint class for map."""

    endpoint = "map"

    def bounding_box(
        self,
        northeast: tuple,
        southwest: tuple,
        timestamp=0,
        limit=0,
        exclude="captured",
        fields="munzee_id,friendly_name,latitude,longitude,original_pin_image,proximity_radius_ft,creator_username",
    ):
        """
        Get deployed Munzees within a Bounding Box. Filter options can be applied.
        It’s possible to get more than one box at a time. Needed data fields can be specified.
        If the number of munzees in a box exceeds the maximum limit of 1000 munzees, returned data for that box will be picked randomly, so try to keep the boxes small.

        :param exclude: comma separated list of munzees status types that will be exluded. options: own, captured, maintenance
        :param fields: comma separated list of data fields for a munzee
        :param limit: maximum number of munzees to return. default: 1000
        :points: JSON encoded list of named bounding boxes to request.
        """
        return self.POST(
            "boundingbox",
            {
                "points": {
                    "box1": {
                        "timestamp": timestamp,
                        "lat1": northeast[0],
                        "lng1": northeast[1],
                        "lat2": southwest[0],
                        "lng2": southwest[1],
                    }
                },
                "exclude": exclude,
                "fields": fields,
                "limit": limit,
            },
        )



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['munzee', 'munzee.endpoints']

package_data = \
{'': ['*']}

install_requires = \
['requests>=2.28.1,<3.0.0']

setup_kwargs = {
    'name': 'munzee',
    'version': '0.1.1',
    'description': 'Python Munzee API wrapper',
    'long_description': '# munzeepy\nPython Munzee API wrapper\n\n![PyPI](https://img.shields.io/pypi/v/munzee)\n\n## Developing\n\nInstall `poe`:\n\n```sh\npipx install poethepoet\n```\n',
    'author': 'MatyiFKBT',
    'author_email': '6183867+MatyiFKBT@users.noreply.github.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



from munzee.endpoint import _Endpoint


class Players(_Endpoint):
    """Endpoint class for players."""

    endpoint = "user"

    def get_current_player(self):
        """
        Get the user's profile.
        """
        return self.GET("current")

    def get_player_by_name(self, name: str):
        """
        Get a player by their name.
        """
        return self.POST("", {"username": name})

    def get_player_by_id(self, user_id: int):
        """
        Get a player by their ID.
        """
        return self.POST("", {"user_id": user_id})



from munzee.endpoint import _Endpoint


class Statzee(_Endpoint):
    """Endpoint class for statzee."""

    endpoint = "statzee"

    def get_daily_stats(self, day: str):
        """
        Get the user's daily stats.
        """
        return self.POST("player/day", {"day": day})



from munzee.endpoint import _Endpoint


class Clans(_Endpoint):
    """Endpoint class for clans."""

    endpoint = "clan"

    def get_clan_id(self, name: str):
        """
        Convert a clan’s simple name into the correcponsing clan ID needed for other requests.
        """
        return self.POST("id", {"simple_name": name})

    def get_clan_details(self, clan_id: int):
        """
        Get details for a specific clan and all clan members. Point values are for the current clan battle.
        """
        return self.POST("", {"clan_id": clan_id})

    def get_clan_statistics(self, clan_id: int):
        """
        Get current statistics for a specific clan.

        Data can be null if there is no data or no clan battle running currently.
        """
        return self.POST("stats", {"clan_id": clan_id})
